@@ -1,6 +1,2 @@
-
-
 /// https://tailwindcss.com/docs/flex-basis
-pub struct FlexSystem {
-
-}
\ No newline at end of file
+pub struct FlexSystem {}
