@@ -1,10 +1,5 @@
 use super::*;
-use nom::{
-    branch::alt,
-    character::complete::digit1,
-    combinator::{map_res, opt, recognize},
-    sequence::tuple,
-};
+use nom::{branch::alt, sequence::tuple};
 
 impl TailwindBorderCollapse {
     pub fn parser<'a>() -> impl FnMut(&'a str) -> ParsedList<'a> {
