@@ -6,12 +6,18 @@ impl CssAttribute {
     }
 }
 
-impl Display for CssAttribute {
+impl Debug for CssAttribute {
     fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
         write!(f, "{}: {};", self.key, self.value)
     }
 }
 
+impl Display for CssAttribute {
+    fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
+        Debug::fmt(self, f)
+    }
+}
+
 impl Eq for CssAttribute {}
 
 impl PartialEq<Self> for CssAttribute {
